@@ -2,15 +2,16 @@ from .token import (
     VercelOidcTokenError,
     get_vercel_oidc_token,
     get_vercel_oidc_token_sync,
-    decode_oidc_payload,
 )
 from .credentials import Credentials, get_credentials
+from .token import decode_oidc_payload, get_token_payload
 
 __all__ = [
     "VercelOidcTokenError",
     "get_vercel_oidc_token",
     "get_vercel_oidc_token_sync",
-    "decode_oidc_payload",
+    "get_token_payload",
     "Credentials",
     "get_credentials",
+    "decode_oidc_payload",
 ]
